pub struct OneShotPending { /* private fields */ }Expand description
Unique authority to perform a one-shot transition.
Implementations
Sourceimpl OneShotPending
impl OneShotPending
Sourcepub proof fn alloc() -> tracked result : Self
pub proof fn alloc() -> tracked result : Self
Creates a pending one-shot transition at a fresh resource location.
Sourcepub proof fn set(tracked self) -> tracked result : OneShotSet
pub proof fn set(tracked self) -> tracked result : OneShotSet
ensures
result.id() == self.id(),Consumes the unique pending authority and marks the transition as set.
Sourcepub proof fn incompatible(tracked &self, tracked set: &OneShotSet)
pub proof fn incompatible(tracked &self, tracked set: &OneShotSet)
ensures
self.id() != set.id(),A pending authority cannot coexist with set knowledge at the same location.